@@ -1,5 +1,10 @@
 from __future__ import absolute_import, division, print_function, unicode_literals
 
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+	from typing import Union
+
 try:
 	from os import makedirs
 
