@@ -1,7 +1,7 @@
 from __future__ import absolute_import, division, print_function, unicode_literals
 
 from future.utils import viewkeys
-import logging, json
+import logging, json, csv
 from itertools import islice
 from functools import partial, wraps
 from datetime import timedelta
@@ -15,7 +15,8 @@ from .filesystem import mdatetime
 from .object import args_to_key
 
 if TYPE_CHECKING:
-	from typing import Any, Callable, Dict, Optional, TextIO, Union, Iterator
+	from typing import Any, Callable, Dict, Optional, TextIO, Union, Iterator, Sequence, Tuple
+	from .compat.pathlib import Path
 	JsonDict = Dict[str, Any]
 
 if __debug__:
@@ -210,7 +211,7 @@ def jl_to_csv(jlpath, csvpath, keyfunc, mode="xt"):
 def key_to_hash(key, default=None):
 	from hashlib import md5
 	binary = json.dumps(key, default=default).encode("utf-8")
-	return md5(binary).hexdigest()
+	return md5(binary).hexdigest()  # nosec
 
 def cache(path, duration=None, ensure_ascii=False, indent=None, sort_keys=False, default=None, object_hook=None):
 	# type: (Path, Optional[timedelta], bool, Optional[str], bool, Optional[Callable], Optional[Callable]) -> Callable
@@ -227,7 +228,7 @@ def cache(path, duration=None, ensure_ascii=False, indent=None, sort_keys=False,
 		@wraps(func)
 		def inner(*args, **kwargs):
 
-			hash = key_to_hash(args_to_key(args, kwargs), default=default)
+			hash = key_to_hash(args_to_key(args, kwargs, {}), default=default)
 			fullpath = path / hash
 
 			try:
@@ -261,7 +262,7 @@ def jsonlines_cache(path, duration=None, ensure_ascii=False, sort_keys=False, de
 		@wraps(func)
 		def inner(*args, **kwargs):
 
-			hash = key_to_hash(args_to_key(args, kwargs))
+			hash = key_to_hash(args_to_key(args, kwargs, {}), default=default)
 			fullpath = path / hash
 
 			try:
