@@ -2,11 +2,28 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 from typing import TYPE_CHECKING
 
+from collections.abc import Iterable, Sized
+
+class SizedIterable(Iterable, Sized):
+	pass
+
 if TYPE_CHECKING:
 
-	from typing import Any, Optional, Sequence
+	from typing import Any, Optional, Sequence, Union
 	from typing_extensions import Protocol
 
+	Number = Union[int, float]
+
+	class Comparable(Protocol):
+
+		def __le__(self, other):
+			# type: (Any, ) -> bool
+			...
+
+		def __ge__(self, other):
+			# type: (Any, ) -> bool
+			...
+
 	class Computable(Protocol):
 
 		def __neg__(self, other):
